@@ -1,28 +1,35 @@
 /*
-SPDX-FileCopyrightText: 2011 Dmitry Risenberg <dmitry.risenberg@gmail.com>
+    SPDX-FileCopyrightText: 2011 Dmitry Risenberg <dmitry.risenberg@gmail.com>
 
-SPDX-License-Identifier: LGPL-2.0-or-later
+    SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #ifndef KOMPAREDIFF2_DIFFERENCESTRINGPAIR_H
 #define KOMPAREDIFF2_DIFFERENCESTRINGPAIR_H
 
+// lib
+#include "differencestring.h"
+// Qt
 #include <QString>
 
-#include "difference.h"
-
-namespace Diff2 {
+namespace KompareDiff2
+{
 
 class Marker;
 class DifferenceString;
 
-class DifferenceStringPair {
+class DifferenceStringPair
+{
 public:
-    DifferenceStringPair(DifferenceString* first, DifferenceString* second)
-        : m_first(first), m_second(second),
-          m_strFirst(QLatin1Char(' ') + first->string()), m_strSecond(QLatin1Char(' ') + second->string()),
-          m_lengthFirst(m_strFirst.length()), m_lengthSecond(m_strSecond.length()),
-          m_arrayFirst(m_strFirst.unicode()), m_arraySecond(m_strSecond.unicode())
+    DifferenceStringPair(DifferenceString *first, DifferenceString *second)
+        : m_first(first)
+        , m_second(second)
+        , m_strFirst(QLatin1Char(' ') + first->string())
+        , m_strSecond(QLatin1Char(' ') + second->string())
+        , m_lengthFirst(m_strFirst.length())
+        , m_lengthSecond(m_strSecond.length())
+        , m_arrayFirst(m_strFirst.unicode())
+        , m_arraySecond(m_strSecond.unicode())
     {
         // Actual contents must be indented by 1
     }
@@ -46,11 +53,11 @@ public:
     {
         return m_second->markerList();
     }
-    void prependFirst(Marker* marker)
+    void prependFirst(Marker *marker)
     {
         m_first->prepend(marker);
     }
-    void prependSecond(Marker* marker)
+    void prependSecond(Marker *marker)
     {
         m_second->prepend(marker);
     }
@@ -59,15 +66,16 @@ public:
         return difference <= qMax(m_lengthFirst, m_lengthSecond) / 2;
     }
     const static bool allowReplace = true;
+
 private:
-    DifferenceString* m_first;
-    DifferenceString* m_second;
+    DifferenceString *m_first;
+    DifferenceString *m_second;
     QString m_strFirst;
     QString m_strSecond;
     unsigned int m_lengthFirst;
     unsigned int m_lengthSecond;
-    const QChar* m_arrayFirst;
-    const QChar* m_arraySecond;
+    const QChar *m_arrayFirst;
+    const QChar *m_arraySecond;
 };
 
 }
